Exceptions
::::::::::

.. toctree::
   :caption: Exceptions
   :maxdepth: 1

   01_intro_exceptions.rst
   02_runtime_stack_and_raise_command.rst
   03_standard_exceptions.rst
   04_principles_for_using_exceptions.rst
   05_exceptions_syntax.rst
   06_the_finally_clause.rst
   glossary.rst
   Exercises.rst
